#include <STC8G.H>
#include <delay.h>
#include <Timer.h>
#include <SMG.h>
#include <IIC.h>
#include <CLOCK.h>
#include <System.h>
#include <intrins.h>
#include <Config.h>

#define DELAY_TIME	5

//
static void I2C_Delay(unsigned char n)
{
    do
    {
        _nop_();_nop_();_nop_();_nop_();_nop_();
        _nop_();_nop_();_nop_();_nop_();_nop_();
        _nop_();_nop_();_nop_();_nop_();_nop_();		
    }
    while(n--);      	
}

//
void I2CStart(void)
{
		EA=0;
    sda = 1;
    scl = 1;
	I2C_Delay(DELAY_TIME);
    sda = 0;
	I2C_Delay(DELAY_TIME);
    scl = 0; 
	EA=1;
}

//
void I2CStop(void)
{
	EA=0;
    sda = 0;
    scl = 1;
	I2C_Delay(DELAY_TIME);
    sda = 1;
	I2C_Delay(DELAY_TIME);
	EA=1;
}

//
void I2CSendByte(unsigned char byt)
{
    unsigned char i;
	EA=0;
    for(i=0; i<8; i++){
        scl = 0;
		I2C_Delay(DELAY_TIME);
        if(byt & 0x80){
            sda = 1;
        }
        else{
            sda = 0;
        }
		I2C_Delay(DELAY_TIME);
        scl = 1;
        byt <<= 1;
		I2C_Delay(DELAY_TIME);
    }
	
    scl = 0;  
		EA=1;
}

//
unsigned char I2CReceiveByte(void)
{
	unsigned char da;
	unsigned char i;
	EA=0;
	for(i=0;i<8;i++){   
		scl = 1;
		I2C_Delay(DELAY_TIME);
		da <<= 1;
		if(sda) 
			da |= 0x01;
		scl = 0;
		I2C_Delay(DELAY_TIME);
	}
	EA=1;
	return da;    
}

//
unsigned char I2CWaitAck(void)
{
	unsigned char ackbit;
	EA=0;
    scl = 1;
	I2C_Delay(DELAY_TIME);
    ackbit = sda; 
    scl = 0;
	I2C_Delay(DELAY_TIME);
	EA=1;
	return ackbit;
}

//
void I2CSendAck(unsigned char ackbit)
{
	EA=0;
    scl = 0;
    sda = ackbit; 
	I2C_Delay(DELAY_TIME);
    scl = 1;
	I2C_Delay(DELAY_TIME);
    scl = 0; 
	sda = 1;
	I2C_Delay(DELAY_TIME);
	EA=1;
}